==> account_kit-3.0.5.tar.gz: lib/ui/containers/ImpersonateContainer.dart <==
import 'package:account_kit/entities/user/user.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/group/groupActions.dart';
import 'package:account_kit/redux/user/userActions.dart';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:redux/redux.dart';

class ImpersonateContainer<T extends VirtualAccountState>
    extends StatefulWidget {
  final int? groupID;
  ImpersonateContainer({this.groupID});
  @override
  _ImpersonatingState createState() => _ImpersonatingState<T>();
}

class _ImpersonatingState<T extends VirtualAccountState>
    extends State<ImpersonateContainer> {
  bool searchEnabled = false;
  TextEditingController editingController = TextEditingController();
  var list = List<User>.empty(growable: true);

  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
      onInitialBuild: (vm) {
        if (widget.groupID != null) {
          vm.getGroupUsers(widget.groupID!);
        } else {
          vm.getUsers();
        }
      },
      converter: (Store<T> store) => _ViewModel.create(store),
      builder: (BuildContext context, _ViewModel viewModel) =>
          _createBody(context, viewModel),
    );
  }

  List<User> getDataSource(_ViewModel vm) {
    if (widget.groupID != null) {
      return vm.groupUsers?[widget.groupID]?.toList() ?? [];
    }
    return vm.users.toList();
  }

  void filterSearchResults(String query, _ViewModel vm) {
    final source = getDataSource(vm);
    if (query.isEmpty) {
      list = source;
    } else {
      var _list = List<User>.empty(growable: true);
      source.forEach((user) {
        if (user.firstName.toLowerCase().contains(query) ||
            user.lastName.toLowerCase().contains(query) ||
            user.email.toLowerCase().contains(query)) {
          _list.add(user);
        }
      });
      setState(() {
        list = _list;
      });
    }
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    final users = searchEnabled ? list : getDataSource(vm);
    final isDark = Theme.of(context).brightness == Brightness.dark;

    return Scaffold(
        appBar: AppBar(
          iconTheme: IconThemeData(
            color:
                isDark ? Colors.white : Colors.black, //change your color here
          ),
          backgroundColor: isDark ? Colors.grey.shade900 : Colors.white,
          title: Text(
            "Select User",
            style: TextStyle(
              color: isDark ? Colors.white : Colors.black,
            ),
          ),
          actions: [
            IconButton(
                icon: Icon(
                  !searchEnabled ? Icons.search : Icons.search_off,
                  color: isDark ? Colors.white : Colors.black,
                ),
                onPressed: () {
                  setState(() {
                    searchEnabled = !searchEnabled;
                  });
                })
          ],
        ),
        body: Column(
          children: [
            if (searchEnabled)
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextField(
                  autofocus: true,
                  onChanged: (e) => filterSearchResults(e.toLowerCase(), vm),
                  controller: editingController,
                  decoration: InputDecoration(
                      labelText: "Search User",
                      hintText: "Search User",
                      prefixIcon: Icon(Icons.search),
                      border: OutlineInputBorder(
                          borderRadius:
                              BorderRadius.all(Radius.circular(25.0)))),
                ),
              ),
            Expanded(
              child: ListView(
                padding: const EdgeInsets.all(16.0),
                children: List.generate(users.length, (index) {
                  final user = users[index];
                  return ListTile(
                    onTap: () {
                      vm.impersonate(user.uuid);
                      Navigator.of(context).pushNamed("/");
                    },
                    title: Text("${user.firstName} ${user.lastName}"),
                    subtitle: Text("${user.email}"),
                    trailing: Icon(Icons.arrow_forward_ios, size: 16),
                  );
                }),
              ),
            ),
          ],
        ));
  }
}

class _ViewModel {
  String? authImpersonateToken;
  BuiltList<User> users;
  Function getUsers;
  Function(int) getGroupUsers;
  Function impersonate;
  BuiltMap<int, BuiltList<User>>? groupUsers;
  _ViewModel(
    this.authImpersonateToken,
    this.users,
    this.getUsers,
    this.getGroupUsers,
    this.impersonate,
    this.groupUsers,
  );

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
        store.state.networkState.authImpersonateToken,
        store.state.accountKitState.userState.users,
        () => store.dispatch(GetUsersAction()),
        (groupID) => store.dispatch(GetGroupUsersAction(groupID: groupID)),
        (uuid) => store.dispatch(ImpersonateAction({}, uuid)),
        store.state.accountKitState.groupState.groupUsers);
  }
}

==> account_kit-3.0.8.tar.gz: lib/ui/containers/ImpersonateContainer.dart <==
import 'package:account_kit/entities/user/user.dart';
import 'package:account_kit/helpers/queryParams.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/group/groupActions.dart';
import 'package:account_kit/redux/user/userActions.dart';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:redux/redux.dart';

class ImpersonateContainer<T extends VirtualAccountState>
    extends StatefulWidget {
  final int? groupID;
  ImpersonateContainer({this.groupID});
  @override
  _ImpersonatingState createState() => _ImpersonatingState<T>();
}

class _ImpersonatingState<T extends VirtualAccountState>
    extends State<ImpersonateContainer> {
  bool searchEnabled = false;
  TextEditingController editingController = TextEditingController();
  var list = List<User>.empty(growable: true);

  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
      onInitialBuild: (vm) {
        if (widget.groupID != null) {
          vm.getGroupUsers(widget.groupID!);
        } else {
          vm.getUsers(getUserQueryParams());
        }
      },
      converter: (Store<T> store) => _ViewModel.create(store),
      builder: (BuildContext context, _ViewModel viewModel) =>
          _createBody(context, viewModel),
    );
  }

  List<User> getDataSource(_ViewModel vm) {
    if (widget.groupID != null) {
      return vm.groupUsers?[widget.groupID]?.toList() ?? [];
    }
    return vm.users.toList();
  }

  void filterSearchResults(String query, _ViewModel vm) {
    final source = getDataSource(vm);
    if (query.isEmpty) {
      list = source;
    } else {
      var _list = List<User>.empty(growable: true);
      source.forEach((user) {
        if (user.firstName.toLowerCase().contains(query) ||
            user.lastName.toLowerCase().contains(query) ||
            user.email.toLowerCase().contains(query)) {
          _list.add(user);
        }
      });
      setState(() {
        list = _list;
      });
    }
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    final users = searchEnabled ? list : getDataSource(vm);
    final isDark = Theme.of(context).brightness == Brightness.dark;

    return Scaffold(
        appBar: AppBar(
          iconTheme: IconThemeData(
            color:
                isDark ? Colors.white : Colors.black, //change your color here
          ),
          backgroundColor: isDark ? Colors.grey.shade900 : Colors.white,
          title: Text(
            "Select User",
            style: TextStyle(
              color: isDark ? Colors.white : Colors.black,
            ),
          ),
          actions: [
            IconButton(
                icon: Icon(
                  !searchEnabled ? Icons.search : Icons.search_off,
                  color: isDark ? Colors.white : Colors.black,
                ),
                onPressed: () {
                  setState(() {
                    searchEnabled = !searchEnabled;
                  });
                })
          ],
        ),
        body: Column(
          children: [
            if (searchEnabled)
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextField(
                  autofocus: true,
                  onChanged: (e) => filterSearchResults(e.toLowerCase(), vm),
                  controller: editingController,
                  decoration: InputDecoration(
                      labelText: "Search User",
                      hintText: "Search User",
                      prefixIcon: Icon(Icons.search),
                      border: OutlineInputBorder(
                          borderRadius:
                              BorderRadius.all(Radius.circular(25.0)))),
                ),
              ),
            Expanded(
              child: ListView(
                padding: const EdgeInsets.all(16.0),
                children: List.generate(users.length, (index) {
                  final user = users[index];
                  return ListTile(
                    onTap: () {
                      vm.impersonate(user.uuid);
                      Navigator.of(context).pushNamed("/");
                    },
                    title: Text("${user.firstName} ${user.lastName}"),
                    subtitle: Text("${user.email}"),
                    trailing: Icon(Icons.arrow_forward_ios, size: 16),
                  );
                }),
              ),
            ),
          ],
        ));
  }
}

class _ViewModel {
  // String? authImpersonateToken;
  BuiltList<User> users;
  Function(Map<String, String>) getUsers;
  Function(int) getGroupUsers;
  Function impersonate;
  BuiltMap<int, BuiltList<User>>? groupUsers;

  _ViewModel(
    // this.authImpersonateToken,
    this.users,
    this.getUsers,
    this.getGroupUsers,
    this.impersonate,
    this.groupUsers,
  );

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
        // store.state.networkState.authImpersonateToken,
        store.state.accountKitState.userState.users,
        (queryParams) => store.dispatch(GetUsersAction(queryParams)),
        (groupID) => store.dispatch(GetGroupUsersAction(groupID: groupID)),
        (uuid) => store.dispatch(ImpersonateAction({}, uuid)),
        store.state.accountKitState.groupState.groupUsers);
  }
}
